import type { Mocks } from './mocks.js';
export * from './index.js';
export { plugin } from './index.js';
export { mockImport } from './mock-import.js';
export { mockRequire } from './mock-require.js';
/**
 * Mocks that have mock data attached
 */
export type MocksWithMocks = Mocks & {
    mocks: Exclude<Mocks['mocks'], undefined>;
};
/**
 * Context information passed to loader methods
 *
 * @internal
 * @group Node Loader API
 */
export interface Context {
    importAssertions: {
        [k: string]: string;
    };
    conditions: string[];
    parentURL?: string;
}
/**
 * Result returned by a `resolve()` method
 *
 * @internal
 * @group Node Loader API
 */
export interface ResolveResult {
    format?: null | 'builtin' | 'commonjs' | 'json' | 'module' | 'wasm';
    importAssertions?: {
        [k: string]: string;
    };
    shortCircuit?: boolean;
    url: string;
}
/**
 * Result returned by a `load()` method
 *
 * @internal
 * @group Node Loader API
 */
export interface LoadResult {
    format: string;
    shortCircuit?: boolean;
    source: string | ArrayBuffer | Uint8Array;
}
/**
 * The next `resolve()` function in the list *
 *
 * @internal
 * @group Node Loader API
 */
export type NextResolveFunction = (url: string, context: Context) => Promise<ResolveResult>;
/**
 * A `resolve()` function in a loader
 *
 * @internal
 * @group Node Loader API
 */
export type ResolveFunction = (url: string, context: Context, nextResolve: NextResolveFunction) => Promise<ResolveResult>;
/**
 * A `load()` function exported by a loader
 *
 * @internal
 * @group Node Loader API
 */
export type LoadFunction = (url: string, context: Context, nextLoad: NextLoadFunction) => Promise<LoadResult>;
/**
 * The next `load()` function in the chain
 *
 * @internal
 * @group Node Loader API
 */
export type NextLoadFunction = (url: string, context: Context) => Promise<LoadResult>;
/**
 * Tell node how to load our `tapmock://` fake modules
 *
 * @internal
 * @group Node Loader API
 */
export declare const load: LoadFunction;
/**
 * Tell node how to resolve our `tapmock://...` synthetic modules,
 * and their mocks.
 *
 * @internal
 * @group Node Loader API
 */
export declare const resolve: ResolveFunction;
//# sourceMappingURL=loader.d.ts.map